@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: backup.php,v 1.1.1.1 2005/06/30 05:03:53 ryu Exp $
+  $Id: backup.php,v 1.2 2007/04/16 05:39:23 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -164,9 +164,9 @@
         tep_set_time_limit(0);
 
         if ($HTTP_GET_VARS['action'] == 'restorenow') {
-          $read_from = $HTTP_GET_VARS['file'];
+          $read_from = tep_db_prepare_input($HTTP_GET_VARS['file']);
           if (file_exists(DIR_FS_BACKUP . $HTTP_GET_VARS['file'])) {
-            $restore_file = DIR_FS_BACKUP . $HTTP_GET_VARS['file'];
+            $restore_file = escapeshellarg(DIR_FS_BACKUP . $HTTP_GET_VARS['file']);
             $extension = substr($HTTP_GET_VARS['file'], -3);
             if ( ($extension == 'sql') || ($extension == '.gz') || ($extension == 'zip') ) {
               switch ($extension) {
@@ -251,7 +251,7 @@
           }
 
           tep_db_query("delete from " . TABLE_CONFIGURATION . " where configuration_key = 'DB_LAST_RESTORE'");
-          tep_db_query("insert into " . TABLE_CONFIGURATION . " values ('', 'Last Database Restore', 'DB_LAST_RESTORE', '" . $read_from . "', 'Last database restore file', '6', '', '', now(), '', '')");
+          tep_db_query("insert into " . TABLE_CONFIGURATION . " values ('', 'Last Database Restore', 'DB_LAST_RESTORE', '" . tep_db_input($read_from) . "', 'Last database restore file', '6', '', '', now(), '', '')");
 
           if ($remove_raw) {
             unlink($restore_from);
