@@ -429,7 +429,11 @@ ryuhei@secondbrain.co.jp
             <td class="main" valign="top"><?php echo TEXT_CATEGORIES_KEYWORDS; ?></td>
             <td class="main">
 <?php
-      $HTTP_POST_VARS['categories_keywords'] = str_replace("", " ", $HTTP_POST_VARS['categories_keywords']);
+      if (function_exists("mbereg_replace")) {
+        $HTTP_POST_VARS['categories_keywords'] = mbereg_replace("", " ", $HTTP_POST_VARS['categories_keywords']);
+      } else {
+        $HTTP_POST_VARS['categories_keywords'] = str_replace("", " ", $HTTP_POST_VARS['categories_keywords']);
+      }
       echo $HTTP_POST_VARS['categories_keywords'] . tep_draw_hidden_field('categories_keywords', $HTTP_POST_VARS['categories_keywords']);
 ?><td>
           </tr>
