@@ -44,7 +44,7 @@ ryuhei@secondbrain.co.jp
       // ʬϤǡȥȥեκ
       $indata = fopen(FILENAME_P_INDATA, "w");
       $titledata = fopen(FILENAME_P_T_INFILE, "w");
-      $products_query = tep_db_query("select p.products_id, p.products_model, p.products_image, p.products_isbn, p.products_price, p.manufacturers_id, p.products_tax_class_id, IF(s.status, s.specials_new_products_price, NULL) as specials_new_products_price, pd.products_name, pd.products_subtitle, pd.products_series_title, pd.products_author, pd.products_publishers, pd.products_published, pd.products_volume, pd.products_description, pd.products_description2, pd.products_keywords from " . TABLE_PRODUCTS . " p, " . TABLE_PRODUCTS_DESCRIPTION . " pd left join " . TABLE_SPECIALS . " s on p.products_id = s.products_id where p.products_status = '1' and pd.products_id = p.products_id and pd.language_id = '" . $languages_id . "'");
+      $products_query = tep_db_query("select p.products_id, p.products_model, p.products_image, p.products_isbn, p.products_price, p.manufacturers_id, p.products_tax_class_id, IF(s.status, s.specials_new_products_price, NULL) as specials_new_products_price, pd.products_name, pd.products_subtitle, pd.products_series_title, pd.products_author, pd.products_publishers, pd.products_published, pd.products_volume, pd.products_description, pd.products_description2, pd.products_keywords from (" . TABLE_PRODUCTS . " p, " . TABLE_PRODUCTS_DESCRIPTION . " pd) left join " . TABLE_SPECIALS . " s on p.products_id = s.products_id where p.products_status = '1' and pd.products_id = p.products_id and pd.language_id = '" . $languages_id . "'");
       while ($products = tep_db_fetch_array($products_query)) {
         $product_contents_id = "<::" . $products['products_id'] . "::>";
         $product_contents = "";
@@ -621,4 +621,4 @@ ryuhei@secondbrain.co.jp
 <br>
 </body>
 </html>
-<?php require(DIR_WS_INCLUDES . 'application_bottom.php'); ?>
\ No newline at end of file
+<?php require(DIR_WS_INCLUDES . 'application_bottom.php'); ?>
