@@ -363,12 +363,17 @@ ryuhei@secondbrain.co.jp
                   }
                 } elseif (($cfg_data[$i][7] == 'N') && (!is_numeric($ok_rec[$i]))) {
                   // ǡץåʿ͡
-                  $up_rec_err_flg = true;
-                  $up_rec_err_count++;
-                  if (is_array($up_rec)) {
-                    $up_rec_err_array[] = array($up_rec_count, $cfg_data[$i][2], implode($ini_data['upfile_delimiter'], $up_rec), $cfg_data[$i][1], ERROR_UPLOAD_DATA_IS_NOT_NUMERIC . $ok_rec[$i]);
+                  if (is_numeric(str_replace(',', '', $ok_rec[$i]))) {
+                    // ǡץåʿͥб
+                    $ok_rec[$i] = str_replace(',', '', $ok_rec[$i]);
                   } else {
-                    $up_rec_err_array[] = array($up_rec_count, $cfg_data[$i][2], $up_rec, $cfg_data[$i][1], ERROR_UPLOAD_DATA_IS_NOT_NUMERIC . $ok_rec[$i]);
+                    $up_rec_err_flg = true;
+                    $up_rec_err_count++;
+                    if (is_array($up_rec)) {
+                      $up_rec_err_array[] = array($up_rec_count, $cfg_data[$i][2], implode($ini_data['upfile_delimiter'], $up_rec), $cfg_data[$i][1], ERROR_UPLOAD_DATA_IS_NOT_NUMERIC . $ok_rec[$i]);
+                    } else {
+                      $up_rec_err_array[] = array($up_rec_count, $cfg_data[$i][2], $up_rec, $cfg_data[$i][1], ERROR_UPLOAD_DATA_IS_NOT_NUMERIC . $ok_rec[$i]);
+                    }
                   }
                 } elseif ($cfg_data[$i][7] == 'D') {
                   if ((!ereg("^([0-9]+)-([0-9]+)-([0-9]+)$", $ok_rec[$i], $date_part)) || (!checkdate($date_part[2], $date_part[3], $date_part[1]))) {
@@ -708,7 +713,7 @@ ryuhei@secondbrain.co.jp
         }
         fclose($download_cfg_file);
        
-        $download_sql = "select " . $select_column_list . " from " . TABLE_PRODUCTS . " p, " . TABLE_PRODUCTS_DESCRIPTION . " pd left join " . TABLE_PRODUCTS_TO_CATEGORIES . " p2c on p.products_id = p2c.products_id where pd.products_id = p.products_id and pd.language_id = '" . tep_db_input($HTTP_POST_VARS['language_id']) . "'";
+        $download_sql = "select " . $select_column_list . " from (" . TABLE_PRODUCTS . " p, " . TABLE_PRODUCTS_DESCRIPTION . " pd) left join " . TABLE_PRODUCTS_TO_CATEGORIES . " p2c on p.products_id = p2c.products_id where pd.products_id = p.products_id and pd.language_id = '" . tep_db_input($HTTP_POST_VARS['language_id']) . "'";
         $download_query = tep_db_query($download_sql);
         while($download = tep_db_fetch_array($download_query)) {
         	 $csv_rec = '';
@@ -721,6 +726,8 @@ ryuhei@secondbrain.co.jp
                 $csv_rec .= ($csv_row_flg ? $ini_data['upfile_delimiter'] . '"' : '"') . $manufacturers_id_array[$download[$column_list[$i]]] . '"';
               } elseif (($column_list[$i] == 'products_price')) {
                 $csv_rec .= ($csv_row_flg ? $ini_data['upfile_delimiter'] . '"' : '"') . (int)$download[$column_list[$i]] . '"';
+              } elseif (($column_list[$i] == 'products_date_available')) {
+                $csv_rec .= ($csv_row_flg ? $ini_data['upfile_delimiter'] . '"' : '"') . (($download[$column_list[$i]] == '0000-00-00 00:00:00') ? '0000-00-00' : date("Y-m-d",strtotime($download[$column_list[$i]]))) . '"';
               } else {
                 $csv_rec .= ($csv_row_flg ? $ini_data['upfile_delimiter'] . '"' : '"') . $download[$column_list[$i]] . '"';
               }
@@ -730,6 +737,8 @@ ryuhei@secondbrain.co.jp
             $csv_row_flg = true;
           }
           // ԤѴ
+          $csv_rec = str_replace("\r\n", "\r", $csv_rec);
+          $csv_rec = str_replace("\r", "\n", $csv_rec);
           $csv_rec = str_replace("\n", "\\n", $csv_rec);
           // ǡν񤭽Ф
           if ($HTTP_POST_VARS['encoding'] == 'SJIS') {
@@ -1580,4 +1589,4 @@ switch ($HTTP_GET_VARS['action']) {
 <br>
 </body>
 </html>
-<?php require(DIR_WS_INCLUDES . 'application_bottom.php'); ?>
\ No newline at end of file
+<?php require(DIR_WS_INCLUDES . 'application_bottom.php'); ?>
