@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: specials.php,v 1.1.1.1 2005/06/30 05:04:02 ryu Exp $
+  $Id: specials.php,v 1.2 2007/04/16 05:39:23 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -35,35 +35,50 @@
       break;
     case 'insert':
 // insert a product on special
-      if (substr($HTTP_POST_VARS['specials_price'], -1) == '%') {
-        $new_special_insert_query = tep_db_query("select products_id, products_price from " . TABLE_PRODUCTS . " where products_id = '" . $HTTP_POST_VARS['products_id'] . "'");
-        $new_special_insert = tep_db_fetch_array($new_special_insert_query);
-        $HTTP_POST_VARS['products_price'] = $new_special_insert['products_price'];
-        $HTTP_POST_VARS['specials_price'] = ($HTTP_POST_VARS['products_price'] - (($HTTP_POST_VARS['specials_price'] / 100) * $HTTP_POST_VARS['products_price']));
-      }	
+      $products_id = tep_db_prepare_input($HTTP_POST_VARS['products_id']);
+      $products_price = tep_db_prepare_input($HTTP_POST_VARS['products_price']);
+      $specials_price = tep_db_prepare_input($HTTP_POST_VARS['specials_price']);
+      $day = tep_db_prepare_input($HTTP_POST_VARS['day']);
+      $month = tep_db_prepare_input($HTTP_POST_VARS['month']);
+      $year = tep_db_prepare_input($HTTP_POST_VARS['year']);
 
-      $expires_date = '';
-      if ($HTTP_POST_VARS['day'] && $HTTP_POST_VARS['month'] && $HTTP_POST_VARS['year']) {
-        $expires_date = $HTTP_POST_VARS['year'];
-        $expires_date .= (strlen($HTTP_POST_VARS['month']) == 1) ? '0' . $HTTP_POST_VARS['month'] : $HTTP_POST_VARS['month'];
-        $expires_date .= (strlen($HTTP_POST_VARS['day']) == 1) ? '0' . $HTTP_POST_VARS['day'] : $HTTP_POST_VARS['day'];
+      if (substr($specials_price, -1) == '%') {
+        $new_special_insert_query = tep_db_query("select products_id, products_price from " . TABLE_PRODUCTS . " where products_id = '" . (int)$products_id . "'");
+        $new_special_insert = tep_db_fetch_array($new_special_insert_query);
+
+        $products_price = $new_special_insert['products_price'];
+        $specials_price = ($products_price - (($specials_price / 100) * $products_price));
       }
 
-      tep_db_query("insert into " . TABLE_SPECIALS . " (products_id, specials_new_products_price, specials_date_added, expires_date, status) values ('" . $HTTP_POST_VARS['products_id'] . "', '" . $HTTP_POST_VARS['specials_price'] . "', now(), '" . $expires_date . "', '1')");
+      $expires_date = '';
+      if (tep_not_null($day) && tep_not_null($month) && tep_not_null($year)) {
+        $expires_date = $year;
+        $expires_date .= (strlen($month) == 1) ? '0' . $month : $month;
+        $expires_date .= (strlen($day) == 1) ? '0' . $day : $day;
+      }
+
+      tep_db_query("insert into " . TABLE_SPECIALS . " (products_id, specials_new_products_price, specials_date_added, expires_date, status) values ('" . (int)$products_id . "', '" . tep_db_input($specials_price) . "', now(), '" . tep_db_input($expires_date) . "', '1')");
       tep_redirect(tep_href_link(FILENAME_SPECIALS, 'page=' . $HTTP_GET_VARS['page']));
       break;
     case 'update':
+      $specials_id = tep_db_prepare_input($HTTP_POST_VARS['specials_id']);
+      $products_price = tep_db_prepare_input($HTTP_POST_VARS['products_price']);
+      $specials_price = tep_db_prepare_input($HTTP_POST_VARS['specials_price']);
+      $day = tep_db_prepare_input($HTTP_POST_VARS['day']);
+      $month = tep_db_prepare_input($HTTP_POST_VARS['month']);
+      $year = tep_db_prepare_input($HTTP_POST_VARS['year']);
+
 // update a product on special
-      if (substr($HTTP_POST_VARS['specials_price'], -1) == '%') $HTTP_POST_VARS['specials_price'] = ($HTTP_POST_VARS['products_price'] - (($HTTP_POST_VARS['specials_price'] / 100) * $HTTP_POST_VARS['products_price']));
+      if (substr($specials_price, -1) == '%') $specials_price = ($products_price - (($specials_price / 100) * $products_price));
 
       $expires_date = '';
-      if ($HTTP_POST_VARS['day'] && $HTTP_POST_VARS['month'] && $HTTP_POST_VARS['year']) {
-        $expires_date = $HTTP_POST_VARS['year'];
-        $expires_date .= (strlen($HTTP_POST_VARS['month']) == 1) ? '0' . $HTTP_POST_VARS['month'] : $HTTP_POST_VARS['month'];
-        $expires_date .= (strlen($HTTP_POST_VARS['day']) == 1) ? '0' . $HTTP_POST_VARS['day'] : $HTTP_POST_VARS['day'];
+      if (tep_not_null($day) && tep_not_null($month) && tep_not_null($year)) {
+        $expires_date = $year;
+        $expires_date .= (strlen($month) == 1) ? '0' . $month : $month;
+        $expires_date .= (strlen($day) == 1) ? '0' . $day : $day;
       }
 
-      tep_db_query("update " . TABLE_SPECIALS . " set specials_new_products_price = '" . $HTTP_POST_VARS['specials_price'] . "', specials_last_modified = now(), expires_date = '" . $expires_date . "' where specials_id = '" . $HTTP_POST_VARS['specials_id'] . "'");
+      tep_db_query("update " . TABLE_SPECIALS . " set specials_new_products_price = '" . tep_db_input($specials_price) . "', specials_last_modified = now(), expires_date = '" . tep_db_input($expires_date) . "' where specials_id = '" . (int)$specials_id . "'");
       tep_redirect(tep_href_link(FILENAME_SPECIALS, 'page=' . $HTTP_GET_VARS['page'] . '&sID=' . $specials_id));
       break;
     case 'deleteconfirm':
