@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: address_book_process.php,v 1.7 2007/06/12 06:02:03 ryu Exp $
+  $Id: address_book_process.php,v 1.8 2009/04/14 23:51:23 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -232,7 +232,12 @@
 <title><?php echo TITLE; ?></title>
 <base href="<?php echo (($request_type == 'SSL') ? HTTPS_SERVER : HTTP_SERVER) . DIR_WS_CATALOG; ?>" />
 <link rel="stylesheet" type="text/css" href="general.css" media="screen,print" />
-<link rel="stylesheet" type="text/css" href="<?php echo substr(FILENAME_ADDRESS_BOOK_PROCESS, 0, strrpos(FILENAME_ADDRESS_BOOK_PROCESS, '.'));?>.css" media="screen,print" />
+<?php 
+  $customCSS = substr(FILENAME_ADDRESS_BOOK_PROCESS, 0, strrpos(FILENAME_ADDRESS_BOOK_PROCESS, '.')). ".css";
+  if (file_exists($customCSS)){
+    echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"$customCSS\" media=\"screen,print\" />";
+  }
+?>
 <script language="javascript"><!--
 function check_form() {
   var error = 0;
