@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: advanced_search.php,v 1.6 2007/06/12 06:02:03 ryu Exp $
+  $Id: advanced_search.php,v 1.8 2009/04/14 23:51:23 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -27,7 +27,12 @@
 <title><?php echo TITLE; ?></title>
 <base href="<?php echo (($request_type == 'SSL') ? HTTPS_SERVER : HTTP_SERVER) . DIR_WS_CATALOG; ?>" />
 <link rel="stylesheet" type="text/css" href="general.css" media="screen,print" />
-<link rel="stylesheet" type="text/css" href="<?php echo substr(FILENAME_ADVANCED_SEARCH, 0, strrpos(FILENAME_ADVANCED_SEARCH, '.'));?>.css" media="screen,print" />
+<?php 
+  $customCSS = substr(FILENAME_ADVANCED_SEARCH, 0, strrpos(FILENAME_ADVANCED_SEARCH, '.')). ".css";
+  if (file_exists($customCSS)){
+    echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"$customCSS\" media=\"screen,print\" />";
+  }
+?>
 <script language="javascript" src="includes/general.js"></script>
 <script language="javascript"><!--
 function check_form() {
@@ -161,7 +166,36 @@ function popupWindow(url) {
   $cssid = 'rightBox';
   $contentbox_header = HEADING_SEARCH_CRITERIA;
   
-  $criteria_box = '<table>' . "\n" .
+  $criteria_box = '';
+  if (isset($HTTP_GET_VARS['errorno'])) {
+    $criteria_box .= '<p class="infoLine"><span class="infoMessage">';
+    if (($HTTP_GET_VARS['errorno'] & 1) == 1) {
+      $criteria_box .= str_replace('\n', '<br />', JS_AT_LEAST_ONE_INPUT);
+    }
+    if (($HTTP_GET_VARS['errorno'] & 10) == 10) {
+      $criteria_box .= str_replace('\n', '<br />', JS_INVALID_FROM_DATE);
+    }
+    if (($HTTP_GET_VARS['errorno'] & 100) == 100) {
+      $criteria_box .= str_replace('\n', '<br />', JS_INVALID_TO_DATE);
+    }
+    if (($HTTP_GET_VARS['errorno'] & 1000) == 1000) {
+      $criteria_box .= str_replace('\n', '<br />', JS_TO_DATE_LESS_THAN_FROM_DATE);
+    }
+    if (($HTTP_GET_VARS['errorno'] & 10000) == 10000) {
+      $criteria_box .= str_replace('\n', '<br />', JS_PRICE_FROM_MUST_BE_NUM);
+    }
+    if (($HTTP_GET_VARS['errorno'] & 100000) == 100000) {
+      $criteria_box .= str_replace('\n', '<br />', JS_PRICE_TO_MUST_BE_NUM);
+    }
+    if (($HTTP_GET_VARS['errorno'] & 1000000) == 1000000) {
+      $criteria_box .= str_replace('\n', '<br />', JS_PRICE_TO_LESS_THAN_PRICE_FROM);
+    }
+    if (($HTTP_GET_VARS['errorno'] & 10000000) == 10000000) {
+      $criteria_box .= str_replace('\n', '<br />', JS_INVALID_KEYWORDS);
+    }
+    $criteria_box .= "</span></p>\n";
+  }
+  $criteria_box .= '<table>' . "\n" .
                  '<tr>' . "\n" .
                  '<th>' . ENTRY_PRODUCTS_NAME . '</th>' . "\n" .
                  '<td>' . tep_draw_input_field('keywords_p_name', '', 'class="advancedSearchInput"') . '</td>' . "\n" .
@@ -251,36 +285,6 @@ function popupWindow(url) {
 
   new contentBox($cssid, $contentbox_contents, $contentbox_header);
 ?>
-<?php
-  if (isset($HTTP_GET_VARS['errorno'])) {
-    echo '<p class="infoLine"><span class="infoMessage">';
-    if (($HTTP_GET_VARS['errorno'] & 1) == 1) {
-      echo str_replace('\n', '<br />', JS_AT_LEAST_ONE_INPUT);
-    }
-    if (($HTTP_GET_VARS['errorno'] & 10) == 10) {
-      echo str_replace('\n', '<br />', JS_INVALID_FROM_DATE);
-    }
-    if (($HTTP_GET_VARS['errorno'] & 100) == 100) {
-      echo str_replace('\n', '<br />', JS_INVALID_TO_DATE);
-    }
-    if (($HTTP_GET_VARS['errorno'] & 1000) == 1000) {
-      echo str_replace('\n', '<br />', JS_TO_DATE_LESS_THAN_FROM_DATE);
-    }
-    if (($HTTP_GET_VARS['errorno'] & 10000) == 10000) {
-      echo str_replace('\n', '<br />', JS_PRICE_FROM_MUST_BE_NUM);
-    }
-    if (($HTTP_GET_VARS['errorno'] & 100000) == 100000) {
-      echo str_replace('\n', '<br />', JS_PRICE_TO_MUST_BE_NUM);
-    }
-    if (($HTTP_GET_VARS['errorno'] & 1000000) == 1000000) {
-      echo str_replace('\n', '<br />', JS_PRICE_TO_LESS_THAN_PRICE_FROM);
-    }
-    if (($HTTP_GET_VARS['errorno'] & 10000000) == 10000000) {
-      echo str_replace('\n', '<br />', JS_INVALID_KEYWORDS);
-    }
-    echo "</span></p>\n";
-  }
-?>
 </div>
 </div>
 </div>
