@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: advanced_search_result.php,v 1.8 2007/06/12 06:02:03 ryu Exp $
+  $Id: advanced_search_result.php,v 1.12 2009/04/14 23:51:23 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -21,13 +21,19 @@
   $errorno = 0;
 
   // 郎åȤƤ뤫ɤΥå
-  if ( (isset($HTTP_GET_VARS['keywords']) && empty($HTTP_GET_VARS['keywords'])) &&
-       (isset($HTTP_GET_VARS['dfrom']) && (empty($HTTP_GET_VARS['dfrom']) || ($HTTP_GET_VARS['dfrom'] == DOB_FORMAT_STRING))) &&
-       (isset($HTTP_GET_VARS['dto']) && (empty($HTTP_GET_VARS['dto']) || ($HTTP_GET_VARS['dto'] == DOB_FORMAT_STRING))) &&
-       (isset($HTTP_GET_VARS['pfrom']) && empty($HTTP_GET_VARS['pfrom'])) &&
-       (isset($HTTP_GET_VARS['pto']) && empty($HTTP_GET_VARS['pto'])) ) {
+  if ((isset($HTTP_GET_VARS['keywords_p_name']) && empty($HTTP_GET_VARS['keywords_p_name'])) &&
+       empty($HTTP_GET_VARS['keywords_p_author']) &&
+       empty($HTTP_GET_VARS['keywords_p_publishers']) &&
+       empty($HTTP_GET_VARS['categories_id']) &&
+       empty($HTTP_GET_VARS['manufacturers_id']) &&
+       (empty($HTTP_GET_VARS['dfrom']) || ($HTTP_GET_VARS['dfrom'] == DOB_FORMAT_STRING)) &&
+       (empty($HTTP_GET_VARS['dto']) || ($HTTP_GET_VARS['dto'] == DOB_FORMAT_STRING)) &&
+       empty($HTTP_GET_VARS['pfrom']) &&
+       empty($HTTP_GET_VARS['pto'])) {
     $errorno += 1;
     $error = 1;
+  } elseif (isset($HTTP_GET_VARS['keywords']) && empty($HTTP_GET_VARS['keywords'])) {
+    tep_redirect(tep_href_link(FILENAME_ADVANCED_SEARCH));
   }
 
   $dfrom_to_check = (($HTTP_GET_VARS['dfrom'] == DOB_FORMAT_STRING) ? '' : $HTTP_GET_VARS['dfrom']);
@@ -105,7 +111,12 @@
 <title><?php echo TITLE; ?></title>
 <base href="<?php echo (($request_type == 'SSL') ? HTTPS_SERVER : HTTP_SERVER) . DIR_WS_CATALOG; ?>" />
 <link rel="stylesheet" type="text/css" href="general.css" media="screen,print" />
-<link rel="stylesheet" type="text/css" href="<?php echo substr(FILENAME_ADVANCED_SEARCH_RESULT, 0, strrpos(FILENAME_ADVANCED_SEARCH_RESULT, '.'));?>.css" media="screen,print" />
+<?php 
+  $customCSS = substr(FILENAME_ADVANCED_SEARCH_RESULT, 0, strrpos(FILENAME_ADVANCED_SEARCH_RESULT, '.')). ".css";
+  if (file_exists($customCSS)){
+    echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"$customCSS\" media=\"screen,print\" />";
+  }
+?>
 </head>
 <body>
 <div id="container">
@@ -278,7 +289,7 @@
     $select_str .= ", SUM(tr.tax_rate) as tax_rate ";
   }
 
-  $from_str = "from " . TABLE_PRODUCTS . " p left join " . TABLE_MANUFACTURERS . " m using(manufacturers_id), " . TABLE_PRODUCTS_DESCRIPTION . " pd left join " . TABLE_SPECIALS . " s on p.products_id = s.products_id, " . TABLE_CATEGORIES . " c, " . TABLE_PRODUCTS_TO_CATEGORIES . " p2c";
+  $from_str = "from (" . TABLE_PRODUCTS . " p left join " . TABLE_MANUFACTURERS . " m using(manufacturers_id), " . TABLE_PRODUCTS_DESCRIPTION . " pd) left join " . TABLE_SPECIALS . " s on p.products_id = s.products_id, " . TABLE_CATEGORIES . " c, " . TABLE_PRODUCTS_TO_CATEGORIES . " p2c";
 
   if ( (DISPLAY_PRICE_WITH_TAX == 'true') && ( (isset($HTTP_GET_VARS['pfrom']) && tep_not_null($HTTP_GET_VARS['pfrom'])) || (isset($HTTP_GET_VARS['pto']) && tep_not_null($HTTP_GET_VARS['pto']))) ) {
     if (!tep_session_is_registered('customer_country_id')) {
@@ -476,7 +487,7 @@
   } else {
     $sort_col = substr($HTTP_GET_VARS['sort'], 0 , 1);
     $sort_order = substr($HTTP_GET_VARS['sort'], 1);
-    $order_str = ' order by p.sort_order, ';
+    $order_str = ' order by ';
     switch ($column_list[$sort_col-1]) {
       case 'PRODUCT_LIST_MODEL':
         $order_str .= "p.products_model " . ($sort_order == 'd' ? "desc" : "") . ", pd.products_name";
