@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: create_account_process.php,v 1.8 2007/06/12 06:02:03 ryu Exp $
+  $Id: create_account_process.php,v 1.9 2009/04/14 23:51:23 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -209,7 +209,12 @@
 <title><?php echo TITLE; ?></title>
 <base href="<?php echo (($request_type == 'SSL') ? HTTPS_SERVER : HTTP_SERVER) . DIR_WS_CATALOG; ?>" />
 <link rel="stylesheet" type="text/css" href="general.css" media="screen,print" />
-<link rel="stylesheet" type="text/css" href="<?php echo substr(FILENAME_CREATE_ACCOUNT_PROCESS, 0, strrpos(FILENAME_CREATE_ACCOUNT_PROCESS, '.'));?>.css" media="screen,print" />
+<?php 
+  $customCSS = substr(FILENAME_CREATE_ACCOUNT_PROCESS, 0, strrpos(FILENAME_CREATE_ACCOUNT_PROCESS, '.')). ".css";
+  if (file_exists($customCSS)){
+    echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"$customCSS\" media=\"screen,print\" />";
+  }
+?>
 <?php require('includes/form_check.js.php'); ?>
 </head>
 <body>
