@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: categories.php,v 1.2 2006/07/16 05:09:34 ryu Exp $
+  $Id: categories.php,v 1.4 2007/05/08 01:48:37 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -17,11 +17,14 @@
     global $foo, $categories_string, $id;
     
     if ($foo[$counter]['level'] > $foo[$counter]['prev_level']) {
-      $categories_string .= "<ul>\n";
+      $categories_string .= "\n<ul>\n";
     } else if ($foo[$counter]['level'] < $foo[$counter]['prev_level']) {
       for ($a=$foo[$counter]['level']; $a<$foo[$counter]['prev_level']; $a++) {
-        $categories_string .= "</ul>\n";
+        $categories_string .= "</li>\n</ul>\n";
       }
+      $categories_string .= "</li>\n";
+    } else {
+      $categories_string .= "</li>\n";
     }
 
     if ( ($id) && (in_array($counter, $id)) ) {
@@ -57,10 +60,10 @@
       }
     }
 
-    $categories_string .= "</li>\n";
-
     if ($foo[$counter]['next_id']) {
       tep_show_category($foo[$counter]['next_id']);
+    } else {
+      $categories_string .= "</li>\n</ul>\n";
     }
   }
 ?>
@@ -73,7 +76,7 @@
 
   unset($prev_id);
   unset($first_element);
-  $categories_query = tep_db_query("select c.categories_id, cd.categories_name, c.parent_id from " . TABLE_CATEGORIES . " c, " . TABLE_CATEGORIES_DESCRIPTION . " cd where c.parent_id = '0' and c.categories_id = cd.categories_id and cd.language_id='" . $languages_id ."' order by sort_order, cd.categories_name");
+  $categories_query = tep_db_query("select c.categories_id, cd.categories_name, c.parent_id from " . TABLE_CATEGORIES . " c, " . TABLE_CATEGORIES_DESCRIPTION . " cd where c.parent_id = '0' and c.categories_id = cd.categories_id and cd.language_id='" . (int)$languages_id ."' order by sort_order, cd.categories_name");
   while ($categories = tep_db_fetch_array($categories_query))  {
     $foo[$categories['categories_id']] = array(
                                         'name' => $categories['categories_name'],
@@ -86,6 +89,8 @@
 
     if (isset($prev_id)) {
       $foo[$prev_id]['next_id'] = $categories['categories_id'];
+    } else {
+      $foo[$categories['categories_id']]['prev_level'] = -1;
     }
 
     $prev_id = $categories['categories_id'];
@@ -103,7 +108,7 @@
     while (list($key, $value) = each($id)) {
       unset($prev_id);
       unset($first_id);
-      $categories_query = tep_db_query("select c.categories_id, cd.categories_name, c.parent_id from " . TABLE_CATEGORIES . " c, " . TABLE_CATEGORIES_DESCRIPTION . " cd where c.parent_id = '" . $value . "' and c.categories_id = cd.categories_id and cd.language_id='" . $languages_id ."' order by sort_order, cd.categories_name");
+      $categories_query = tep_db_query("select c.categories_id, cd.categories_name, c.parent_id from " . TABLE_CATEGORIES . " c, " . TABLE_CATEGORIES_DESCRIPTION . " cd where c.parent_id = '" . (int)$value . "' and c.categories_id = cd.categories_id and cd.language_id='" . (int)$languages_id ."' order by sort_order, cd.categories_name");
       $category_check = tep_db_num_rows($categories_query);
       if ($category_check > 0) {
         $new_path .= $value;
@@ -143,9 +148,7 @@
       }
     }
   }
-  $categories_string = "<ul>\n";
   tep_show_category($first_element); 
-  $categories_string .= "</ul>";
 
   $infobox_contents = array();
   $infobox_contents[] = array('text'  => $categories_string);
