@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: address_book.php,v 1.1.1.1 2005/06/30 05:04:17 ryu Exp $
+  $Id: address_book.php,v 1.2 2006/07/16 05:09:35 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -20,6 +20,6 @@ define('TABLE_HEADING_NUMBER', 'No.');
 define('TABLE_HEADING_NAME', '̾');
 define('TABLE_HEADING_LOCATION', 'Ի');
 define('TEXT_NO_ENTRIES_IN_ADDRESS_BOOK', 'ޤɥ쥹ĢϿϤޤ...');
-define('TEXT_MAXIMUM_ENTRIES', '<span class="addressBookAttention">:</span> ɥ쥹Ģˤ %s ޤϿǤޤ');
-define('TEXT_MAXIMUM_ENTRIES_REACHED', '<span class="addressBookAttention">:</span> ɥ쥹Ģ¤ %s ޤϿޤ');
+define('TEXT_MAXIMUM_ENTRIES', ': ɥ쥹Ģˤ %s ޤϿǤޤ');
+define('TEXT_MAXIMUM_ENTRIES_REACHED', ': ɥ쥹Ģ¤ %s ޤϿޤ');
 ?>
\ No newline at end of file
