@@ -17,7 +17,6 @@ ryuhei@secondbrain.co.jp
   define('MODULE_PAYMENT_COD_TABLE_YAMATO_TEXT_FEE', ':');
   define('MODULE_PAYMENT_COD_TABLE_YAMATO_TEXT_OVERFLOW_ERROR', '㤤夲ۤ¤Ķᤪ갷Ǥޤ');
   define('MODULE_PAYMENT_COD_TABLE_YAMATO_TEXT_MAILFOOTER',
-  'ʤˡ׶(%s)(%s)äۤ' . "\n"
-. 'ãˤʧ' . "\n\n"
-. EMAIL_SIGNATURE);
+  'ʤˡޤˤ' . "\n"
+. 'ãˤʧ');
 ?>
\ No newline at end of file
