@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: cod_table_nipponex.php,v 1.3 2006/07/16 05:09:36 ryu Exp $
+  $Id: cod_table_nipponex.php,v 1.4 2007/04/16 05:40:47 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -44,7 +44,7 @@
 
       if ( ($this->enabled == true) && ((int)MODULE_PAYMENT_COD_TABLE_NIPPONEX_ZONE > 0) ) {
         $check_flag = false;
-        $check_query = tep_db_query("select zone_id from " . TABLE_ZONES_TO_GEO_ZONES . " where geo_zone_id = '" . MODULE_PAYMENT_COD_TABLE_NIPPONEX_ZONE . "' and zone_country_id = '" . $order->billing['country']['id'] . "' order by zone_id");
+        $check_query = tep_db_query("select zone_id from " . TABLE_ZONES_TO_GEO_ZONES . " where geo_zone_id = '" . MODULE_PAYMENT_COD_TABLE_NIPPONEX_ZONE . "' and zone_country_id = '" . (int)$order->billing['country']['id'] . "' order by zone_id");
         while ($check = tep_db_fetch_array($check_query)) {
           if ($check['zone_id'] < 1) {
             $check_flag = true;
