@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: sagawaex.php,v 1.2 2006/06/12 09:31:31 ryu Exp $
+  $Id: sagawaex.php,v 1.3 2007/04/16 05:40:59 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -49,7 +49,7 @@
 
       if ( ($this->enabled == true) && ((int)MODULE_SHIPPING_SAGAWAEX_ZONE > 0) ) {
         $check_flag = false;
-        $check_query = tep_db_query("select zone_id from " . TABLE_ZONES_TO_GEO_ZONES . " where geo_zone_id = '" . MODULE_SHIPPING_SAGAWAEX_ZONE . "' and zone_country_id = '" . $order->delivery['country']['id'] . "' order by zone_id");
+        $check_query = tep_db_query("select zone_id from " . TABLE_ZONES_TO_GEO_ZONES . " where geo_zone_id = '" . MODULE_SHIPPING_SAGAWAEX_ZONE . "' and zone_country_id = '" . (int)$order->delivery['country']['id'] . "' order by zone_id");
         while ($check = tep_db_fetch_array($check_query)) {
           if ($check['zone_id'] < 1) {
             $check_flag = true;
@@ -81,7 +81,7 @@
       $zone_id    = $order->delivery['zone_id'];
 
       if (in_array($country_id, $this->sagawaex_countries_nbr)) {
-          $zoneinfo = tep_db_query("SELECT zone_code FROM zones WHERE zone_id = '".$zone_id."'");
+          $zoneinfo = tep_db_query("SELECT zone_code FROM zones WHERE zone_id = '". (int)$zone_id ."'");
           $a_zonevalues = tep_db_fetch_array($zoneinfo);
           $s_zone_code = $a_zonevalues['zone_code'];
 
