@@ -28,7 +28,7 @@ ryuhei@secondbrain.co.jp
 
       if ( ($this->enabled == true) && ((int)MODULE_SHIPPING_SASSI_ZONE > 0) ) {
         $check_flag = false;
-        $check_query = tep_db_query("select zone_id from " . SASSI_ZONES_TO_GEO_ZONES . " where geo_zone_id = '" . MODULE_SHIPPING_SASSI_ZONE . "' and zone_country_id = '" . $order->delivery['country']['id'] . "' order by zone_id");
+        $check_query = tep_db_query("select zone_id from " . SASSI_ZONES_TO_GEO_ZONES . " where geo_zone_id = '" . MODULE_SHIPPING_SASSI_ZONE . "' and zone_country_id = '" . (int)$order->delivery['country']['id'] . "' order by zone_id");
         while ($check = tep_db_fetch_array($check_query)) {
           if ($check['zone_id'] < 1) {
             $check_flag = true;
