@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: products_new.php,v 1.4 2006/07/16 05:09:36 ryu Exp $
+  $Id: products_new.php,v 1.5 2007/05/07 06:51:47 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -53,7 +53,7 @@
       echo ((KN_CFG_USE_PUBLISHERS == 'true') && ($products_new_array[$i]['publishers']) ? '<li class="pPublishers">' . $products_new_array[$i]['publishers'] . "</li>\n" : '');
       echo ((KN_CFG_USE_VOLUME == 'true') && ($products_new_array[$i]['volume']) ? '<li class="pVolume">' . $products_new_array[$i]['volume'] . "</li>\n" : '');
       echo ((KN_CFG_USE_PUBLISHED == 'true') && ($products_new_array[$i]['published']) ? '<li class="pPublished">' . $products_new_array[$i]['published'] . "</li>\n" : '');
-      echo '<li class="pDescription">' . $products_new_array[$i]['products_description'] . "</li>\n";
+      echo '<li class="pDescription">' . $products_new_array[$i]['description'] . "</li>\n";
       echo "</ul>\n";
       echo '<p class="pPrice">' . $products_price . '</p>' . "\n";
       if (!defined("KN_CFG_ALLOW_CHECKOUT") || (KN_CFG_ALLOW_CHECKOUT == "true")) {
