@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: login.php,v 1.7 2007/06/12 06:02:03 ryu Exp $
+  $Id: login.php,v 1.8 2009/04/14 23:51:23 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -85,7 +85,12 @@
 <title><?php echo TITLE; ?></title>
 <base href="<?php echo (($request_type == 'SSL') ? HTTPS_SERVER : HTTP_SERVER) . DIR_WS_CATALOG; ?>" />
 <link rel="stylesheet" type="text/css" href="general.css" media="screen,print" />
-<link rel="stylesheet" type="text/css" href="<?php echo substr(FILENAME_LOGIN, 0, strrpos(FILENAME_LOGIN, '.'));?>.css" media="screen,print" />
+<?php 
+  $customCSS = substr(FILENAME_LOGIN, 0, strrpos(FILENAME_LOGIN, '.')). ".css";
+  if (file_exists($customCSS)){
+    echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"$customCSS\" media=\"screen,print\" />";
+  }
+?>
 <script language="javascript"><!--
 function session_win() {
   window.open("<?php echo tep_href_link(FILENAME_INFO_SHOPPING_CART); ?>","info_shopping_cart","height=460,width=430,toolbar=no,statusbar=no,scrollbars=yes").focus();
