@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: password_forgotten.php,v 1.7 2007/06/12 06:02:03 ryu Exp $
+  $Id: password_forgotten.php,v 1.9 2009/04/14 23:51:23 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -51,7 +51,12 @@
 <title><?php echo TITLE; ?></title>
 <base href="<?php echo (($request_type == 'SSL') ? HTTPS_SERVER : HTTP_SERVER) . DIR_WS_CATALOG; ?>" />
 <link rel="stylesheet" type="text/css" href="general.css" media="screen,print" />
-<link rel="stylesheet" type="text/css" href="<?php echo substr(FILENAME_PASSWORD_FORGOTTEN, 0, strrpos(FILENAME_PASSWORD_FORGOTTEN, '.'));?>.css" media="screen,print" />
+<?php 
+  $customCSS = substr(FILENAME_PASSWORD_FORGOTTEN, 0, strrpos(FILENAME_PASSWORD_FORGOTTEN, '.')). ".css";
+  if (file_exists($customCSS)){
+    echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"$customCSS\" media=\"screen,print\" />";
+  }
+?>
 </head>
 <body>
 <div id="container">
@@ -81,6 +86,7 @@
     echo '<p class="caution">' .  TEXT_NO_EMAIL_ADDRESS_FOUND . '</p>' . "\n";
   }
 ?>
+<p><?php echo ENTRY_FORGOTTEN_EMAIL_MESSAGE; ?></p>
 <p><?php echo ENTRY_FORGOTTEN_EMAIL_ADDRESS . tep_draw_input_field('email_address', '', 'maxlength="96"'); ?></p>
 <div class="buttonLine">
 <p class="buttonLeft"><a href="<?php echo tep_href_link(FILENAME_LOGIN, '', 'SSL') . '">' . tep_image_button('button_back.gif', IMAGE_BUTTON_BACK) . '</a>'; ?></p>
